# Copyright (C) 2010 Alejandro Ochoa, Singh Research Group, Princeton University
# This file is part of dPUC.
# dPUC is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
# dPUC is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
# You should have received a copy of the GNU General Public License along with dPUC.  If not, see <http://www.gnu.org/licenses/>.

package ParseAln;
use lib '.';
use General;
use strict;

sub fastaInNonAlnHash {
    # reads regular fasta, returns hash structure
    my ($fi) = @_;
    
    # a few variables
    my %id2seq;
    my @ids; # to remember the order of the IDs
    my $currId = '';
    my $currSeq = '';
    
    # read in file
    my $fhi = General::getInFh($fi);
    while (<$fhi>) {
	chomp;
	if (s/^>//) {
	    if ($currSeq) { # so that nothing happens for the first protein name
		$id2seq{$currId} = $currSeq; # store last id/sequence pair
		$currSeq = ''; # now erase it to make way for next sequence
	    }
	    $currId = $_; # update protein name
	    push @ids, $currId;
	}
	else {
	    s/\s+//g; # remove all whitespace
	    $currSeq .= $_; # add to previous buffer
	}
    }
    close $fhi;
    $id2seq{$currId} = $currSeq; # store very last id/sequence pair
    
    # done, return
    return (\%id2seq, \@ids);
}

1;
